@@ -100,10 +100,10 @@ class ClUpdateAction(Action):
          ],
          'condition': lambda Get: Get('cl_update_sync_only_set') == 'off'
          },
-        {'name': 'update:update_perl',
+        {'name': 'update_other:update_perl',
          'group': __("Updating Perl"),
          'tasks': [
-             {'name': 'update:perl_cleaner',
+             {'name': 'update_other:perl_cleaner',
               'message': __('Find & rebuild packages and Perl header files '
                             'broken due to a perl upgrade'),
               'method': 'Update.emergelike("perl-cleaner", "all")',
